Learn R Programming

sisus (version 3.9-12)

sisus.run: driver program for SISUS

Description

runs the stable isotope analysis using the specified Excel-like workbook input dataset

Usage

sisus.run(filename)

Arguments

filename
The Excel workbook name. A modified version of sisus_*_templateX.xls template workbook available in the package sisus/exec folder and at http://statacumen.com/sisus/

Value

  • no value returned, many output files produced depending on options specified in workbook

References

Erhardt, Erik Barry. SISUS: Stable Isotope Sourcing using Sampling, Getting Started. May 30, 2007 http://statacumen.com/sisus/

Examples

Run this code
# set working directory for many output files with setwd()

# see http://statacumen.com/sisus for workbook

filename = "http://statacumen.com/sw/sisus/examples/SISUS_v0_09_template.xls";

sisus.run(filename)

Run the code above in your browser using DataLab